@@ -136,7 +136,7 @@ def main():
                     )
                 )
                 if ARGS_PARSER.quiet:
-                    print(compute_requirement.name)
+                    print(compute_requirement.id)
                 print_log(
                     f"Provisioned {link_entity(CONFIG_COMMON.url, compute_requirement)}"
                 )
@@ -268,9 +268,10 @@ def create_compute_requirement_from_json(cr_json_file: str, prefix: str = "") ->
     )
     name = cr_data["requirementName"]
     if response.status_code == 200:
-        print_log(f"Provisioned Compute Requirement '{name}'")
+        id = response.json()["id"]
+        print_log(f"Provisioned Compute Requirement '{name}' ({id})")
         if ARGS_PARSER.quiet:
-            print(name)
+            print(id)
     else:
         print_error(f"Failed to provision Compute Requirement '{name}'")
         raise Exception(f"{response.text}")
